/**
 * classe LireVoiture (Application)
 * lecture d'un certain nombre de voitures dans un fichier
 * et affichage
 * @author Matthias Colin
 * @version 1.0 (9/06/2009)
 */

import java.io.*;
import java.util.List;
import java.util.ArrayList;

public class LireVoiture {


	/**
	 * lecture d'une liste de Voitures dans un fichier
	 * @param nomFichier le nom du fichier contenant la sauvegarde
	 * @return la liste de voitures lues
	 * @throws IOException (et ses dérivées) en cas de problème de sauvegarde
	 */
	private static List<Voiture> lireVoiture(String nomFichier, int
				nombreVoitures) throws IOException,	ClassNotFoundException {
		List<Voiture> liste; // Liste des voitures à lire
		ObjectInputStream in; // flux d'objet en provenance du fichier

		liste = new ArrayList<Voiture>(nombreVoitures);

		// ouverture du fichier contenant les voitures
		in = new ObjectInputStream(new FileInputStream(nomFichier));

		// lecture des voitures
		for (int i=0; i< nombreVoitures; i++) {
			liste.add( (Voiture) in.readObject());
		}
		in.close();
		return liste;
	}
	
	/**
	 * affichage du mode d'emploi de la'application
	 */		
	private static void printUsage() {
		System.err.println("Usage : ");
		System.err.println("java LireVoiture nomFichier nombreVoitures");
	}

	/**
	 * méthode principale de l'application
	 * @param args contient le nom du fichier et nombre de voitures à lire
	 */
	public static void main(String[] args) {
		String nomFichier = "";
		int nombreVoitures;
		List<Voiture> liste;

		try {
			// traitement des paramètres
			if (args.length<2) {
				printUsage();
				System.exit(-1);
			}
			nomFichier = args[0];
			nombreVoitures = Integer.parseInt(args[1]);
	
			// lecture et affichage des voitures
			for (Voiture voiture : lireVoiture(nomFichier, nombreVoitures)) {
				System.out.println(voiture);
			}
		} catch (NumberFormatException e) {
			printUsage();
		} catch (ClassCastException e) {
			System.err.println("Le fichier " + nomFichier + 
					" ne contient pas de CDThèque : " + e.getMessage());
		} catch (ClassNotFoundException e) {
			System.err.println("Le fichier " + nomFichier + 
					" ne contient pas de CDThèque : " + e.getMessage());
		} catch (InvalidClassException e) {
			System.err.println("Le fichier " + nomFichier + 
					" ne contient pas de CDThèque conforme à ce logiciel : " 
					+ e.getMessage());
		} catch (StreamCorruptedException e) {
			System.err.println("Le fichier " + nomFichier + " est corrompu : " 
					+ e.getMessage());
		} catch (OptionalDataException e) {
			System.err.println("Le fichier " + nomFichier + 
					" contient des données qui ne sont pas de type CDTheque : " 
					+ e.getMessage());
		} catch (FileNotFoundException e) {
			System.err.println("Le fichier " + nomFichier + 
					" n'existe pas ou ne peut être lu : " + e.getMessage());
		} catch (IOException e) {
				System.err.println("Problème d'entrée/sortie avec le fichier " 
						+ nomFichier + " : " + e.getMessage());
		}
	}
}
